@@ -21,7 +21,7 @@ class Measure:
 
     no_log = ()
 
-    #measurement name, overide in subclass
+    #measurement name, override in subclass
     measurement_name = "Base"
 
     required_chans = {
@@ -670,7 +670,6 @@ class Measure:
         with open(fname, "rt") as csv_f:
             # create dict reader
             reader = csv.DictReader(csv_f)
-            print(f"reader header: {reader.fieldnames}")
             # create empty list
             data = []
             # create set for audio clips
